/// <reference types="node" />
import { PathLike } from 'fs';
import BaseClass from './base-class';
import { SignedUploadUrlData } from '../types/launch';
export default class FileUpload extends BaseClass {
    /**
     * @method run
     *
     * @return {*}  {Promise<void>}
     * @memberof FileUpload
     */
    run(): Promise<void>;
    private handleExistingProject;
    private confirmRedeployment;
    private confirmLatestRedeployment;
    private handleNewProject;
    /**
     * @method createNewProject - Create new launch project
     *
     * @return {*}  {Promise<void>}
     * @memberof FileUpload
     */
    createNewProject(uploadUid: string): Promise<void>;
    /**
     * @method prepareForNewProjectCreation - prepare necessary data for new project creation
     *
     * @return {*}  {Promise<void>}
     * @memberof FileUpload
     */
    prepareAndUploadNewProjectFile(): Promise<string>;
    /**
     * @method fileValidation - validate the working directory
     *
     * @memberof FileUpload
     */
    fileValidation(): void;
    /**
     * @method archive - Archive the files and directory to be uploaded for launch project
     *
     * @return {*}
     * @memberof FileUpload
     */
    archive(): Promise<{
        zipName: string;
        zipPath: string;
        projectName: string;
    }>;
    /**
     * @method createSignedUploadUrl - create pre signed url for file upload
     *
     * @return {*}  {Promise<SignedUploadUrlData>}
     * @memberof FileUpload
     */
    createSignedUploadUrl(): Promise<SignedUploadUrlData>;
    /**
     * @method uploadFile - Upload file in to s3 bucket
     *
     * @param {string} fileName
     * @param {PathLike} filePath
     * @return {*}  {Promise<void>}
     * @memberof FileUpload
     */
    uploadFile(fileName: string, filePath: PathLike, signedUploadUrlData: SignedUploadUrlData): Promise<void>;
    private submitFormData;
    private uploadWithHttpClient;
}
