"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLaunchHubUrl = exports.selectProject = exports.selectOrg = exports.getOrganizations = void 0;
const tslib_1 = require("tslib");
const map_1 = tslib_1.__importDefault(require("lodash/map"));
const find_1 = tslib_1.__importDefault(require("lodash/find"));
const isEmpty_1 = tslib_1.__importDefault(require("lodash/isEmpty"));
const cli_utilities_1 = require("@contentstack/cli-utilities");
const graphql_1 = require("../graphql");
async function getOrganizations(options, skip = 0, organizations = []) {
    const { log, managementSdk } = options;
    const configOrgUid = cli_utilities_1.configHandler.get('oauthOrgUid');
    try {
        if (configOrgUid) {
            const response = await managementSdk.organization(configOrgUid).fetch();
            organizations.push(...[response]);
        }
        else {
            const response = await managementSdk
                .organization()
                .fetchAll({ limit: 100, asc: 'name', include_count: true, skip });
            organizations.push(...response.items);
            if (organizations.length < response.count) {
                organizations = await getOrganizations(options, skip + 100, organizations);
            }
        }
    }
    catch (error) {
        log('Unable to fetch organizations.', 'warn');
        log(error, 'error');
        process.exit(1);
    }
    return organizations;
}
exports.getOrganizations = getOrganizations;
async function selectOrg(options) {
    var _a, _b;
    const { log, config, flags } = options;
    const organizations = await getOrganizations(options);
    if (flags.org || config.currentConfig.organizationUid) {
        config.currentConfig.organizationUid =
            ((_a = (0, find_1.default)(organizations, { uid: flags.org })) === null || _a === void 0 ? void 0 : _a.uid) ||
                ((_b = (0, find_1.default)(organizations, {
                    uid: config.currentConfig.organizationUid,
                })) === null || _b === void 0 ? void 0 : _b.uid);
        if (!config.currentConfig.organizationUid) {
            log('Organization UID not found!', 'warn');
        }
    }
    if (!config.currentConfig.organizationUid) {
        config.currentConfig.organizationUid = await cli_utilities_1.cliux
            .inquire({
            type: 'search-list',
            name: 'Organization',
            choices: organizations,
            message: 'Choose an organization',
        })
            .then((name) => { var _a; return (_a = (0, find_1.default)(organizations, { name })) === null || _a === void 0 ? void 0 : _a.uid; });
    }
}
exports.selectOrg = selectOrg;
/**
 * @method selectProject - select projects
 *
 * @return {*}  {Promise<void>}
 * @memberof Logs
 */
async function selectProject(options) {
    var _a, _b, _c;
    const { log, config, flags, apolloClient } = options;
    const projects = await apolloClient
        .query({ query: graphql_1.projectsQuery, variables: { query: {} } })
        .then(({ data: { projects } }) => projects)
        .catch((error) => {
        log('Unable to fetch projects.!', { color: 'yellow' });
        log(error, 'error');
        process.exit(1);
    });
    const listOfProjects = (0, map_1.default)(projects.edges, ({ node: { uid, name } }) => ({
        name,
        value: name,
        uid,
    }));
    if ((0, isEmpty_1.default)(listOfProjects)) {
        log('Project not found', 'info');
        process.exit(1);
    }
    if (config.project || config.currentConfig.uid) {
        config.currentConfig.uid =
            ((_a = (0, find_1.default)(listOfProjects, {
                uid: flags.project,
            })) === null || _a === void 0 ? void 0 : _a.uid) ||
                ((_b = (0, find_1.default)(listOfProjects, {
                    name: flags.project,
                })) === null || _b === void 0 ? void 0 : _b.uid) ||
                ((_c = (0, find_1.default)(listOfProjects, {
                    uid: config.currentConfig.uid,
                })) === null || _c === void 0 ? void 0 : _c.uid);
    }
    if (!config.currentConfig.uid) {
        config.currentConfig.uid = await cli_utilities_1.cliux
            .inquire({
            type: 'search-list',
            name: 'Project',
            choices: listOfProjects,
            message: 'Choose a project',
        })
            .then((name) => { var _a; return (_a = (0, find_1.default)(listOfProjects, { name })) === null || _a === void 0 ? void 0 : _a.uid; });
    }
}
exports.selectProject = selectProject;
function getLaunchHubUrl() {
    const { cma } = cli_utilities_1.configHandler.get('region') || {};
    if (!cma) {
        throw new Error('Region not configured. Please set the region with command $ csdx config:set:region');
    }
    let launchHubBaseUrl = cma.replace('api', 'launch-api');
    if (launchHubBaseUrl.startsWith('http')) {
        launchHubBaseUrl = launchHubBaseUrl.split('//')[1];
    }
    launchHubBaseUrl = launchHubBaseUrl.startsWith('dev11') ? launchHubBaseUrl.replace('dev11', 'dev') : launchHubBaseUrl;
    launchHubBaseUrl = launchHubBaseUrl.endsWith('io') ? launchHubBaseUrl.replace('io', 'com') : launchHubBaseUrl;
    return `https://${launchHubBaseUrl}`;
}
exports.getLaunchHubUrl = getLaunchHubUrl;
